@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: ar.h,v 1.16 2000/06/13 20:34:44 ezust Exp $
+ $Id: ar.h,v 1.18 2001/02/07 20:53:47 mjarrett Exp $
 
  ark -- archiver for the KDE project
 
@@ -36,7 +36,7 @@
 // ark includes
 #include "arch.h"
 
-class ArArch : public Arch 
+class ArArch : public Arch
 {
   Q_OBJECT
 public:
@@ -46,19 +46,16 @@ public:
 
   virtual void open();
   virtual void create();
-	
+
   virtual void addFile( QStringList* );
   virtual void addDir(const QString &) {} // never gets called
 
   virtual void remove(QStringList *);
-  virtual void unarchFile(QStringList *, const QString & _destDir="");
-
-protected slots:
-  void slotReceivedTOC(KProcess *, char *, int);
+  virtual void unarchFile(QStringList *, const QString & _destDir="",
+			  bool viewFriendly=false);
 
 private:
   void setHeaders();
-  void processLine( char *_line );
 };
 
 #endif /* ARARCH_H */
