@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: arkapp.h,v 1.9 2000/05/16 18:52:14 ezust Exp $
+ $Id: arkapp.h,v 1.11 2000/10/08 20:24:14 faure Exp $
 
  ark -- archiver for the KDE project
 
@@ -33,11 +33,12 @@
 #include <kuniqueapp.h>
 #include "arkwidget.h"
 
+#include <qdict.h>
+
 class ArkSettings;
 
 #include <stdlib.h>
 #include <string.h>
-#include <hash_map>
 
 class EqualKey
 {
@@ -48,9 +49,6 @@ public:
     }
 };
 
-// defines HashTable for obtaining ArkWidget pointers given a filename
-typedef hash_map<QString, ArkWidget *, hash<char*>,EqualKey> HashTable;
-
 // This class follows the singleton pattern.
 
 class ArkApplication : public KUniqueApplication
@@ -77,8 +75,10 @@ public:
 
   // use this function to access data from other modules.
   static ArkApplication *getInstance();
+
 protected:
   ArkApplication();
+
 private:
   QWidget *m_mainwidget;  // to be the parent of all ArkWidgets
   int m_windowCount;
@@ -87,7 +87,9 @@ private:
 
   // a hash to obtain the window associated with a filename.
   // given a QString key, you get an ArkWidget * pointer.
-  HashTable m_windowsHash;
+  QDict<ArkWidget> m_windowsHash;
+
+  bool m_isSessionRestored;
 
   static ArkApplication *mInstance; 
 };
