@@ -1,6 +1,6 @@
 /*
 
- $Id: arkwidget.cc,v 1.111 2000/10/13 20:31:48 waba Exp $
+ $Id: arkwidget.cc,v 1.125 2001/02/05 14:10:07 mjarrett Exp $
 
  ark -- archiver for the KDE project
 
@@ -60,6 +60,8 @@
 #include <ktempfile.h>
 #include <progressbase.h>
 #include <kmimemagic.h>
+#include <kedittoolbar.h>
+#include <kstddirs.h>
 // c includes
 
 #include <errno.h>
@@ -107,7 +109,7 @@
 
 #include "viewer.h"
 
-extern int errno;
+//extern int errno;
 
 bool Utilities::haveDirPermissions(const QString &strFile)
 {
@@ -192,10 +194,13 @@ ArkWidget::ArkWidget( QWidget *, const char *name ) :
     m_settings = new ArkSettings;
     // Creates a temp directory for this ark instance
     unsigned int pid = getpid();
-    QString tmpdir;
-    tmpdir.sprintf( "/tmp/ark.%d/", pid );
-    QString ex( "mkdir " + tmpdir + " &>/dev/null" );
-    system( QFile::encodeName(ex) );
+    QString tmpdir,directory;
+    directory.sprintf( "ark.%d/", pid );
+    tmpdir = locateLocal( "tmp", directory );
+
+
+    /*QString ex( "mkdir " + tmpdir + " &>/dev/null" );
+      system( QFile::encodeName(ex) );*/
 
     m_settings->setTmpDir( tmpdir );
 
@@ -341,11 +346,19 @@ void ArkWidget::setupActions()
   statusbarAction = KStdAction::showStatusbar(this, SLOT(toggleStatusBar()), actionCollection());
   KStdAction::saveOptions(this, SLOT(options_saveNow()), actionCollection());
   KStdAction::keyBindings(this, SLOT(options_keys()), actionCollection());
-
+  KStdAction::configureToolbars(this, SLOT(editToolbars()), actionCollection());
 
   createGUI();
 }
 
+
+void ArkWidget::editToolbars()
+{
+  KEditToolbar dlg(actionCollection());
+  if (dlg.exec())
+    createGUI( );
+}
+
 void ArkWidget::setHeader()
 {
   // called after the QTimer goes off after toggling menu bar to hide it.
@@ -428,7 +441,8 @@ void ArkWidget::initialEnables()
   extractAction->setEnabled(false);
   addFileAction->setEnabled(false);
   addDirAction->setEnabled(false);
-
+  openWithAction->setEnabled(false);
+  editAction->setEnabled(false);
 }
 
 
@@ -460,11 +474,11 @@ void ArkWidget::updateStatusTotals()
     strInfo = i18n("Total: 0 Files");
   else if (m_nNumFiles == 1)
     strInfo = i18n("Total: 1 File %1 KB")
-      .arg(KGlobal::locale()->formatNumber(m_nSizeOfFiles, 0));
+      .arg(KGlobal::locale()->formatNumber(m_nSizeOfFiles / 1024.0, 1));
   else
     strInfo = i18n("Total: %1 Files %1 KB")
       .arg(KGlobal::locale()->formatNumber(m_nNumFiles, 0))
-      .arg(KGlobal::locale()->formatNumber(m_nSizeOfFiles, 0));
+      .arg(KGlobal::locale()->formatNumber(m_nSizeOfFiles / 1024.0, 1));
 
   m_pStatusLabelTotal->setText(strInfo);
 }
@@ -601,9 +615,6 @@ void ArkWidget::file_open(const QString & strFile)
     // Set the current archive filename to the filename
   m_strArchName = strFile;
 
-  // add it to the application-wide list of open archives
-  ArkApplication::getInstance()->addOpenArk(strFile, this);
-
   // display the archive contents
   showZip(strFile);
   kdDebug(1601) << "-ArkWidget::file_open(const QString & strFile)" << endl;
@@ -622,10 +633,11 @@ bool ArkWidget::download(const KURL &url, QString &strFile)
     {
       QString extension;
       getArchType(url.path(), extension);
-      mpTempFile = new KTempFile("/tmp/ark", extension);
+      QString directory = locateLocal( "tmp", "ark" );
+      mpTempFile = new KTempFile(directory , extension);
       strFile = mpTempFile->name();
-      kdDebug(1601) << "Downloading " << url.path().local8Bit() << " as " <<
-	strFile.local8Bit() << endl;
+      kdDebug(1601) << "Downloading " << url.path() << " as " <<
+	strFile << endl;
     }
   return KIO::NetAccess::download(url, strFile);
 }
@@ -721,7 +733,7 @@ KURL ArkWidget::getCreateFilename(const QString & _caption,
 	return QString::null;
 
       kdDebug(1601) << "Trying to create an archive named " <<
-	strFile.local8Bit() << endl;
+	strFile << endl;
       if (stat(strFile.local8Bit(), &statbuffer) != -1)  // already exists!
 	{
 	  choice =
@@ -786,9 +798,12 @@ void ArkWidget::file_new()
   KURL url = getCreateFilename(i18n("Create a New Archive"),
 			       m_settings->getFilter());
   strFile = url.path();
-  m_settings->clearShellOutput();
   if (!strFile.isEmpty())
-    createArchive( strFile );
+    {
+        m_settings->clearShellOutput();
+	file_close();
+	createArchive( strFile );
+    }
 }
 
 void ArkWidget::slotCreate(Arch * _newarch, bool _success,
@@ -865,7 +880,7 @@ void ArkWidget::file_open(const KURL& url)
     if (download(url, strFile))
     {
         m_settings->clearShellOutput();
-        kdDebug(1601) << "Recent open: " << strFile.local8Bit() << endl;
+        kdDebug(1601) << "Recent open: " << strFile << endl;
         file_open(strFile);
     }
   }
@@ -893,8 +908,11 @@ void ArkWidget::slotOpen(Arch *_newarch, bool _success,
 	QFileInfo fi( _filename );
 	QString path = fi.dirPath( true );
 	m_settings->setLastOpenDir( path );
+	QString dirtmp;
+	QString directory("tmp.");
+	dirtmp = locateLocal( "tmp", directory );
 
-	if (_filename.left(9) == QString("/tmp/ark.") ||
+	if (_filename.left(9) == /*QString("/tmp/ark.")*/dirtmp ||
 	    !fi.isWritable())
 	  {
 	    _newarch->setReadOnly(true);
@@ -910,6 +928,8 @@ void ArkWidget::slotOpen(Arch *_newarch, bool _success,
 	QString extension;
 	m_bIsSimpleCompressedFile =
 	  (getArchType(m_strArchName, extension) == COMPRESSED_FORMAT);
+
+	ArkApplication::getInstance()->addOpenArk(_filename, this);
     }
   fixEnables();
   QApplication::restoreOverrideCursor();
@@ -999,7 +1019,9 @@ void ArkWidget::slotExtractDone()
 	   it != mDragFiles.end(); ++it)
 	{
 	  QString URL;
-	  URL.sprintf("/tmp/ark.%d/", getpid());
+	  QString directory;
+	  directory.sprintf("ark.%d/", getpid());
+	  URL = locateLocal( "tmp", directory );
 	  URL += *it;
 	  list.append( QUriDrag::localFileToUri(URL) );
 	}
@@ -1135,7 +1157,7 @@ void ArkWidget::fixEnables() // private
   bool bAddDirSupported = true;
   QString extension;
   enum ArchType archtype = getArchType(m_strArchName, extension);
-  if (archtype == ZOO_FORMAT || archtype == AA_FORMAT)
+  if (archtype == ZOO_FORMAT || archtype == AA_FORMAT || archtype == COMPRESSED_FORMAT)
     bAddDirSupported = false;
 
   if (arch)
@@ -1203,13 +1225,14 @@ void ArkWidget::file_close()
       if (archiveContent)
 	{
 	  archiveContent->clear();
+	  clearHeaders();
 	}
       setCentralWidget(0);
       ArkApplication::getInstance()->removeOpenArk(m_strArchName);
       if (mpTempFile)
 	{
 	  kdDebug(1601) << "Removing temp file " <<
-	    mpTempFile->name().local8Bit() << endl;
+	    mpTempFile->name() << endl;
 	  mpTempFile->unlink();
 	  delete mpTempFile;
 	  mpTempFile = NULL;
@@ -1227,6 +1250,7 @@ void ArkWidget::window_close()
     file_close();
     saveProperties();
     kdDebug(1601) << "-ArkWidget::window_close" << endl;
+    close();
 }
 
 
@@ -1367,7 +1391,7 @@ void ArkWidget::createRealArchive(const QString &strFilename)
 {
   FileListView *flw = fileList();
   FileLVI *flvi = (FileLVI*)flw->firstChild();
-  m_compressedFile = flvi->getFileName().local8Bit();
+  m_compressedFile = flvi->getFileName();
   QString tmpdir = m_settings->getTmpDir();
   m_compressedFile = "file:" + tmpdir + "/" + m_compressedFile;
   kdDebug(1601) << "The compressed file is " << m_compressedFile << endl;
@@ -1458,7 +1482,7 @@ void ArkWidget::addFile(QStringList *list)
       for (QStringList::Iterator it = list->begin(); it != list->end(); ++it)
 	{
 	  QString str = *it;
-	  kdDebug(1601) << "Want to add " << str.local8Bit() << endl;
+	  kdDebug(1601) << "Want to add " << str<< endl;
 	  if (str.left(5) == QString("file:"))
 	    {
 	      bNotLocal = false;
@@ -1477,7 +1501,7 @@ void ArkWidget::addFile(QStringList *list)
     }
   arch->addFile(list);
 }
-
+#include <iostream.h>
 void ArkWidget::action_add_dir()
 {
   QString dirName
@@ -1669,7 +1693,7 @@ bool ArkWidget::reportExtractFailures(const QString & _dest,
     FileLVI *flvi = (FileLVI*)flw->firstChild();
     while (flvi)
       {
-	tmp = flvi->getFileName().local8Bit();
+	tmp = flvi->getFileName();
 	_list->append(tmp);
 	flvi = (FileLVI*)flvi->itemBelow();
       }
@@ -1856,7 +1880,7 @@ void ArkWidget::showFile( FileLVI *_pItem )
 			      _pItem->text(getSizeColumn()).toLong()))
     {
       disableAll();
-      arch->unarchFile(m_extractList, m_settings->getTmpDir() );
+      arch->unarchFile(m_extractList, m_settings->getTmpDir(), true);
     }
 }
 
@@ -1946,13 +1970,13 @@ void ArkWidget::updateStatusSelection()
     {
       strInfo = i18n("0 Files Selected");
     }
-  if (m_nNumSelectedFiles != 1)
+  else if (m_nNumSelectedFiles != 1)
     {
-      strInfo = i18n("%1 Files Selected %1 KB").arg(KGlobal::locale()->formatNumber(m_nNumSelectedFiles, 0)).arg(KGlobal::locale()->formatNumber(m_nSizeOfSelectedFiles, 0));
+      strInfo = i18n("%1 Files Selected %1 KB").arg(KGlobal::locale()->formatNumber(m_nNumSelectedFiles, 0)).arg(KGlobal::locale()->formatNumber(m_nSizeOfSelectedFiles / 1024.0, 1));
     }
   else
     {
-    strInfo = i18n("1 File Selected %1 KB").arg(KGlobal::locale()->formatNumber(m_nSizeOfSelectedFiles, 0));
+    strInfo = i18n("1 File Selected %1 KB").arg(KGlobal::locale()->formatNumber(m_nSizeOfSelectedFiles / 1024.0, 1));
     }
   m_pStatusLabelSelect->setText(strInfo);
   fixEnables();
@@ -2258,9 +2282,7 @@ bool ArkWidget::badBzipName(const QString & _filename)
 
 void ArkWidget::createArchive( const QString & _filename )
 {
-
   // make sure we can write there
-
   Arch * newArch = 0;
   QString extension;
   switch( getArchType( _filename, extension) )
@@ -2315,7 +2337,7 @@ void ArkWidget::createArchive( const QString & _filename )
 //////////////////////////////////////////////////////////////////////
 //////////////////////// openArchive /////////////////////////////////
 //////////////////////////////////////////////////////////////////////
-
+    
 void ArkWidget::openArchive(const QString & _filename )
 {
   // figure out what kind of archive it is
@@ -2345,6 +2367,7 @@ void ArkWidget::openArchive(const QString & _filename )
     case AA_FORMAT:
       newArch = new ArArch( m_settings, m_viewer, _filename );
       break;
+    case   UNKNOWN_FORMAT:
     default:
       if (!badBzipName(_filename))
 	{
@@ -2370,6 +2393,9 @@ void ArkWidget::openArchive(const QString & _filename )
 	       return;
 	     }
 	}
+    else
+        return;
+    break;
     }
 
   if (!newArch->utilityIsAvailable())
@@ -2421,12 +2447,15 @@ void ArkWidget::setHeaders(QStringList *_headers,
 {
   int i = 0;
   m_currentSizeColumn = -1;
+
+  clearHeaders();
+
   for ( QStringList::Iterator it = _headers->begin();
 	it != _headers->end(); ++it, ++i )
     {
       QString str = *it;
        archiveContent->addColumn(str);
-       if (str.contains(i18n("Size")))
+       if (SIZE_STRING == str)
 	 m_currentSizeColumn = i;
     }
 
@@ -2437,4 +2466,11 @@ void ArkWidget::setHeaders(QStringList *_headers,
     }
 }
 
+void ArkWidget::clearHeaders()
+{
+	while(archiveContent->columns() > 0) 
+		archiveContent->removeColumn(0);
+}
+
+
 #include "arkwidget.moc"
