@@ -1,6 +1,6 @@
 /*
 
- $Id: tar.cc,v 1.40 2000/08/01 16:06:38 bieker Exp $
+ $Id: tar.cc,v 1.44 2001/02/07 20:53:47 mjarrett Exp $
 
  ark -- archiver for the KDE project
 
@@ -58,12 +58,17 @@
 #include <kmessagebox.h>
 #include <ktempfile.h>
 #include <kmimemagic.h>
+#include <kstddirs.h>
 
 // ark includes
 #include "viewer.h"
 #include "extractdlg.h"
 #include "tar.h"
 #include "tar.moc"
+// David Faure (resident miracle worker) has provided a better KTarGz
+// Until 'tar' is more reliable, or kdelibs' KTar handles large archives
+// better, stick with the safe code.
+#include "ktar.h"
 
 static char *makeAccessString(mode_t mode);
 static QString makeTimeStamp(const QDateTime & dt);
@@ -89,17 +94,20 @@ TarArch::TarArch( ArkSettings *_settings, Viewer *_gui,
     {
       compressed = true;
       QString tmpdir;
-      tmpdir.sprintf("/tmp/ark.%d", getpid());
+      QString directory;
+      directory.sprintf("ark.%d/", getpid());
+      tmpdir = locateLocal( "tmp", directory );
+      //tmpdir.sprintf("/tmp/ark.%d", getpid());
 
       QString base = m_filename.right(m_filename.length()- 1 -
 				     m_filename.findRev("/"));
       base = base.left(base.findRev("."));
-      
+
       // build the temp file name
-      
+
       KTempFile *pTempFile = new KTempFile(tmpdir +
-					   QString::fromLatin1("/temp_tar"),
-					   QString::fromLatin1(".tar"));
+					   QString::fromLocal8Bit("/temp_tar"),
+					   QString::fromLocal8Bit(".tar"));
 
       tmpfile = pTempFile->name();
       kdDebug(1601) << "Tmpfile will be " << tmpfile << "\n" << endl;
@@ -166,7 +174,7 @@ QString TarArch::getCompressor()
 				       m_filename.findRev('.') );
   kdDebug(1601) << "Extension: " << extension << endl;
 
-  if( extension == ".tgz" || extension == ".gz" ) 
+  if( extension == ".tgz" || extension == ".gz" )
     return QString( "gzip" );
   if( extension == ".bz")
     return QString( "bzip" );
@@ -202,19 +210,19 @@ void TarArch::open()
   kdDebug(1601) << "+TarArch::open" << endl;
   unlink( QFile::encodeName(tmpfile) ); // just to make sure
   setHeaders();
-  KTarGz *tarptr;
+  KTarGz2 *tarptr;
 
   if (!compressed || 
       getUnCompressor() == QString("gunzip"))
     {
-      tarptr = new KTarGz(m_filename);
+      tarptr = new KTarGz2(m_filename);
     }
   else
     {
       createTmp();
       while (compressed && createTmpInProgress)
 	qApp->processEvents(); // wait for temp to be created;
-      tarptr = new KTarGz(tmpfile);
+      tarptr = new KTarGz2(tmpfile);
     }
 
   if (! tarptr->open(IO_ReadOnly))
@@ -258,7 +266,7 @@ void TarArch::slotListingDone(KProcess *_kp)
   delete _kp;
 }
 
-void TarArch::processDir(const KTarDirectory *tardir, const QString & root)
+void TarArch::processDir(const KTarDirectory2 *tardir, const QString & root)
   // process a KTarDirectory. Called recursively for directories within
   // directories, etc. Prepends to filename root, for relative pathnames.
 {
@@ -266,7 +274,7 @@ void TarArch::processDir(const KTarDirectory *tardir, const QString & root)
   QStringList list = tardir->entries();
   for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
     {
-      const KTarEntry* tarEntry = tardir->entry((*it));
+      const KTarEntry2* tarEntry = tardir->entry((*it));
       if (tarEntry == NULL)
 	return;
       QStringList col_list;
@@ -291,7 +299,7 @@ void TarArch::processDir(const KTarDirectory *tardir, const QString & root)
       QString strSize = "0";
       if (tarEntry->isFile())
 	{
-	  strSize.sprintf("%d", ((KTarFile *)tarEntry)->size());
+	  strSize.sprintf("%d", ((KTarFile2 *)tarEntry)->size());
 	}
       col_list.append(strSize);
       QString timestamp = makeTimeStamp(tarEntry->datetime());
@@ -302,7 +310,7 @@ void TarArch::processDir(const KTarDirectory *tardir, const QString & root)
       // if it isn't a file, it's a directory - process it.
       // remember that name is root + / + the name of the directory
       if (!tarEntry->isFile())
-	processDir( (KTarDirectory *)tarEntry, name);
+	processDir( (KTarDirectory2 *)tarEntry, name);
     }
   kdDebug(1601) << "-TarArch::processDir" << endl;
 }                                                                           
@@ -600,7 +608,8 @@ void TarArch::slotAddFinished(KProcess *_kp)
   kdDebug(1601) << "-TarArch::slotAddFinished" << endl;
 }
 
-void TarArch::unarchFile( QStringList * _fileList, const QString & _destDir)
+void TarArch::unarchFile(QStringList * _fileList, const QString & _destDir,
+			 bool viewFriendly)
 {
   kdDebug(1601) << "+TarArch::unarchFile" << endl;
   QString dest;
@@ -635,7 +644,7 @@ void TarArch::unarchFile( QStringList * _fileList, const QString & _destDir)
       for ( QStringList::Iterator it = _fileList->begin();
 	    it != _fileList->end(); ++it ) 
 	{
-	  *kp << (*it).latin1() ;
+	  *kp << (*it).local8Bit();/*.latin1() ;*/
 	}
     }
 
