@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: tar.h,v 1.25 2000/06/13 20:34:44 ezust Exp $
+ $Id: tar.h,v 1.27 2001/02/07 20:53:47 mjarrett Exp $
 
   ark -- archiver for the KDE project
 
@@ -41,14 +41,13 @@
 
 // KDE includes
 #include <kprocess.h>
-#include <ktar.h>
 
 // ark includes
-
 #include "arch.h"
 #include "arksettings.h"
 
 class Viewer;
+class KTarDirectory2;
 
 // TarArch can read Tar files and Tar files compressed with gzip.
 // It doesn't yet know how to list Tar files compressed with other
@@ -70,7 +69,8 @@ public:
   virtual void addFile( QStringList *);
   virtual void addDir(const QString &);
   virtual void remove(QStringList *);
-  virtual void unarchFile(QStringList *, const QString & _destDir="");
+  virtual void unarchFile(QStringList *, const QString & _destDir="",
+			  bool viewFriendly=false);
 	
   virtual int getEditFlag();
 
@@ -91,7 +91,7 @@ private:  // methods
   void updateArch();
   void createTmp();
   void setHeaders();
-  void processDir(const KTarDirectory *tardir, const QString & root);
+  void processDir(const KTarDirectory2 *tardir, const QString & root);
   void deleteOldFiles(QStringList *list, bool bAddOnlyNew);
   QString getEntry(const QString & filename);
 
@@ -107,7 +107,6 @@ private: // data
   // for use with deleteOldFiles
   bool deleteInProgress;
   FILE *fd;
-  
 };
 
 #endif /* TAR_H */
