@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: zip.h,v 1.23 2000/06/13 20:34:44 ezust Exp $
+ $Id: zip.h,v 1.25 2001/02/07 20:53:47 mjarrett Exp $
 
   ark -- archiver for the KDE project
 
@@ -56,21 +56,17 @@ public:
   virtual void addDir(const QString & _dirName);
 
   virtual void remove(QStringList *);
-  virtual void unarchFile(QStringList *, const QString & _destDir="");
+  virtual void unarchFile(QStringList *, const QString & _destDir="",
+			  bool viewFriendly=false);
 	
   void testIntegrity();
 
   enum AddMode { Update = 1, Freshen, Move };
 
-protected:
-  bool m_header_removed, m_finished, m_error;
-		
 protected slots:
   void slotIntegrityExited(KProcess*);
-  void slotReceivedTOC(KProcess *, char *, int);
-	
+
 private:
-  void processLine( char* );	
   void setHeaders();
 };
 
