@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: zoo.h,v 1.5 2000/06/13 20:34:44 ezust Exp $
+ $Id: zoo.h,v 1.7 2001/02/07 20:53:47 mjarrett Exp $
 
  ark -- archiver for the KDE project
 
@@ -48,16 +48,13 @@ public:
   virtual void addDir(const QString & _dirName);
 
   virtual void remove(QStringList *);
-  virtual void unarchFile(QStringList *, const QString & _destDir="");
-
-protected:
-  bool m_header_removed, m_finished, m_error;
+  virtual void unarchFile(QStringList *, const QString & _destDir="",
+			  bool viewFriendly=false);
 
 protected slots:
-  void slotReceivedTOC(KProcess *, char *, int);
-	
+  virtual bool processLine(const QCString &line);
+
 private:
-  void processLine( char* );	
   void initExtract( bool, bool, bool );
   void setHeaders();
 };
