@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kdessh.cpp,v 1.3 2000/05/27 16:48:09 hausmann Exp $
+ * $Id: kdessh.cpp,v 1.5 2000/07/31 19:33:42 bieker Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -27,6 +27,7 @@
 #include <klocale.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
+#include <kmessagebox.h>
 
 #include <kdesu/ssh.h>
 #include <kdesu/client.h>
@@ -34,16 +35,15 @@
 
 #include "sshdlg.h"
 
-#define ERR strerror(errno)
 
-const char *Version = "1.0";
-
-static KCmdLineOptions options[] = {
+static KCmdLineOptions options[] = 
+{
     { "+host", I18N_NOOP("Specifies the remote host"), 0 }, 
     { "+command", I18N_NOOP("The command to run."), 0 },
     { "u <user>", I18N_NOOP("Specifies the target uid"), 0 },
+    { "s <path>", I18N_NOOP("Specify remote stub location"), "kdesu_stub" },
     { "n", I18N_NOOP("Do not keep password."), 0 },
-    { "s", I18N_NOOP("Stop the daemon (forgets all passwords)."), 0 },
+    { "q", I18N_NOOP("Stop the daemon (forgets all passwords)."), 0 },
     { "t", I18N_NOOP("Enable terminal output (no password keeping)."), 0 },
     { 0, 0, 0 }
 };
@@ -52,7 +52,7 @@ static KCmdLineOptions options[] = {
 int main(int argc, char *argv[])
 {
     KAboutData aboutData("kdessh", I18N_NOOP("KDE ssh"),
-	    Version, I18N_NOOP("Runs a program on a remote host."),
+	    VERSION, I18N_NOOP("Runs a program on a remote host."),
 	    KAboutData::License_Artistic, 
 	    "Copyright (c) 2000 Geert Jansen");
     aboutData.addAuthor("Geert Jansen", I18N_NOOP("Maintainer"),
@@ -60,11 +60,12 @@ int main(int argc, char *argv[])
 
     KCmdLineArgs::init(argc, argv, &aboutData);
     KCmdLineArgs::addCmdLineOptions(options);
-    KApplication *app = new KApplication;
+
+    KApplication app;
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
     // Stop daemon and exit?
-    if (args->isSet("s")) 
+    if (args->isSet("q")) 
     {
 	KDEsuClient client;
 	if (client.ping() == -1)
@@ -81,8 +82,11 @@ int main(int argc, char *argv[])
 	exit(1);
     }
 
+    if (args->count() < 2)
+	KCmdLineArgs::usage(i18n("No command or host specified!"));
+
     // Check if ssh is available
-    if (KStandardDirs::findExe("ssh").isEmpty()) 
+    if (KStandardDirs::findExe(QString::fromLatin1("ssh")).isEmpty()) 
     {
 	kdError(1511) << "ssh not found\n";
 	exit(1);
@@ -101,9 +105,10 @@ int main(int argc, char *argv[])
 	user = pw->pw_name;
     }
 
+    // Remote stub location
+    QCString stub = args->getOption("s");
+
     // Get remote host, command
-    if (args->count() < 2)
-	KCmdLineArgs::usage(i18n("No command or host specified!"));
     QCString host = args->arg(0);
     QCString command = args->arg(1);
     for (int i=2; i<args->count(); i++) 
@@ -119,7 +124,8 @@ int main(int argc, char *argv[])
     {
 	kdWarning(1511) << "Daemon not safe (not sgid), not using it.\n";
 	have_daemon = false;
-    } else if ((client.ping() == -1) && (client.startServer() == -1))
+    } 
+    else if ((client.ping() == -1) && (client.startServer() == -1))
     {
 	kdWarning(1511) << "Could not start daemon, reduced functionality.\n";
 	have_daemon = false;
@@ -131,7 +137,7 @@ int main(int argc, char *argv[])
     if (keep && !terminal)
     {
 	client.setHost(host);
-	if (client.exec(command,user) != -1)
+	if (client.exec(command, user) != -1)
 	    return 0;
     }
 
@@ -141,23 +147,33 @@ int main(int argc, char *argv[])
     rlim.rlim_cur = rlim.rlim_max = 0;
     if (setrlimit(RLIMIT_CORE, &rlim)) 
     {
-	kdError(1511) << "rlimit(): " << ERR << "\n";
+	kdError(1511) << "rlimit(): " << perror << "\n";
 	exit(1);
     }
 
 
     // Read configuration
     KConfig *config = KGlobal::config();
-    config->setGroup("Passwords");
-    int timeout = config->readNumEntry("Timeout", defTimeout);
+    config->setGroup(QString::fromLatin1("Passwords"));
+    int timeout = config->readNumEntry(QString::fromLatin1("Timeout"), defTimeout);
 
     SshProcess proc(host, user);
-    QCString prompt = proc.checkNeedPassword();
-    QCString password;
-
-    if (!prompt.isEmpty()) 
+    proc.setStub(stub);
+    int needpw = proc.checkNeedPassword();
+    if (needpw < 0)
     {
-	KDEsshDialog *dlg = new KDEsshDialog(host, user, prompt, keep && !terminal);
+	QString msg = i18n("Ssh returned with an error!\n"
+		"The error message is:\n\n");
+	msg += proc.error();
+	KMessageBox::error(0L, msg);
+	exit(1);
+    }
+
+    QCString password;
+    if (needpw != 0)
+    {
+	KDEsshDialog *dlg = new KDEsshDialog(host, user, stub, 
+		proc.prompt(), keep && !terminal);
 	dlg->addLine(i18n("Command"), command);
 	int res = dlg->exec();
 	if (res == KDEsshDialog::Rejected)
@@ -168,7 +184,8 @@ int main(int argc, char *argv[])
     } else 
 	keep = 0; 
 
-    delete app;
+    // Make the dialog go away.
+    app.processEvents();
 
     // Run command
     if (keep && have_daemon) 
@@ -178,7 +195,7 @@ int main(int argc, char *argv[])
 	return client.exec(command, user);
     } else 
     {
-	SshProcess proc(host, user, command);
+	proc.setCommand(command);
 	proc.setTerminal(terminal);
 	proc.setErase(true);
 	return proc.exec(password);
