@@ -1,9 +1,9 @@
 /*
  * kdfwidget.cpp
  *
- * $Id: kdfwidget.cpp,v 1.20 2000/08/12 22:50:21 faure Exp $
+ * $Id: kdfwidget.cpp,v 1.24 2000/12/26 16:47:54 mike Exp $
  *
- * Copyright (c) 1998 Michael Kropfberger <michael.kropfberger@gmx.net>
+ * Copyright (c) 1998-2001 Michael Kropfberger <michael.kropfberger@gmx.net>
  *
  * Requires the Qt widget libraries, available at no cost at
  * http://www.troll.no/
@@ -40,6 +40,7 @@
 #include <qtimer.h>
 #include <qlayout.h>
 
+#include <kdebug.h>
 #include <kapp.h> 
 #include <kcmenumngr.h>
 #include <kglobal.h>
@@ -71,7 +72,7 @@ KDFWidget::KDFWidget( QWidget *parent, const char *name, bool init )
 
   mTabProp.resize(8);
   mTabProp[0] = new CTabEntry( "Icon", i18n("Icon"), true, 32);
-  mTabProp[1] = new CTabEntry( "Device", i18n("Device"), false, 80);
+  mTabProp[1] = new CTabEntry( "Device", i18n("Device"), true, 80);
   mTabProp[2] = new CTabEntry( "Type", i18n("Type"), true, 50);
   mTabProp[3] = new CTabEntry( "Size", i18n("Size"), true, 72);
   mTabProp[4] = new CTabEntry( "MountPoint", i18n("Mount point"), true, 90 );
@@ -90,10 +91,10 @@ KDFWidget::KDFWidget( QWidget *parent, const char *name, bool init )
     mList->setFrameStyle( QFrame::WinPanel + QFrame::Sunken );
     mList->setShowSortIndicator(true);
     connect( mList, 
-      SIGNAL( rightButtonPressed( QListViewItem *, const QPoint &, int )),
+      SIGNAL( pressed( QListViewItem *, const QPoint &, int )),
       this, SLOT( rightButtonPressed( QListViewItem *, const QPoint &, int )));
     connect( mList, 
-      SIGNAL( rightButtonClicked( QListViewItem *, const QPoint &, int )),
+      SIGNAL( clicked( QListViewItem *, const QPoint &, int )),
       this, SLOT( rightButtonClicked( QListViewItem *, const QPoint &, int )));
     connect( mList->header(), SIGNAL(sizeChange(int, int, int)),
       this, SLOT(columnSizeChanged(int, int, int)) );
@@ -122,9 +123,9 @@ void KDFWidget::makeColumns( void )
 
   //
   // 1999-11-29 Espen Sand
-  // This smells like a bad hack but I need to to remove the headers
+  // This smells like a bad hack but I need to remove the headers
   // first. If I don't, the list look like shit afterwards. The iterator
-  // is just used to pervent an endless loop. With my Qt (1999-11-10 ?)
+  // is just used to prevent an endless loop. With my Qt (1999-11-10 ?)
   // I only need as many iterations as there are header items but who knows
   // what a new Qt can do!
   //
@@ -140,22 +141,9 @@ void KDFWidget::makeColumns( void )
   {
     CTabEntry &e = *mTabProp[i];
     if( e.mVisible == true )
-    {
       mList->addColumn( e.mName, e.mWidth );
-    }
-  }
-
-  if( mTabProp[BAR_COLUMN]->mVisible == true )
-  {
-    mBarColumn = -1;
-    for( i=0; i<mTabProp.size(); i++ )
-    {
-      if( mTabProp[i]->mVisible ) { mBarColumn += 1; }
-    }
-  }
-  else
-  {
-    mBarColumn = -1;
+    else
+      mList->addColumn( e.mName, 0 ); // zero width makes it invisible
   }
 
 }
@@ -163,7 +151,7 @@ void KDFWidget::makeColumns( void )
 
 
 
-
+/******************************************************************/
 void KDFWidget::closeEvent(QCloseEvent *)
 {
   applySettings(); 
@@ -178,6 +166,9 @@ void KDFWidget::settingsChanged( void )
 }
 
 
+/***************************************************************************
+  * writes the KConfig
+**/
 void KDFWidget::applySettings( void )
 {
   KConfig &config = *kapp->config();
@@ -190,12 +181,12 @@ void KDFWidget::applySettings( void )
   }
   if( GUI ) 
   {
-    for( uint i=0,j=0; i<mTabProp.size(); i++ )
+    for( uint i=0; i<mTabProp.size(); i++ )
     {
       CTabEntry &e = *mTabProp[i];
       if( e.mVisible == true )
       {
-	e.mWidth = mList->columnWidth(j++);
+	e.mWidth = mList->columnWidth(i);
       }
       config.writeEntry( e.mRes, e.mWidth );
     }
@@ -228,6 +219,8 @@ void KDFWidget::loadSettings( void )
       CTabEntry &e = *mTabProp[i];
       e.mWidth = config.readNumEntry( e.mRes, e.mWidth );
     }
+    if (mTabProp[usageCol]->mWidth > 16) 
+      mTabProp[usageCol]->mWidth -= 16;
 
     config.setGroup("KDFConfig");
     for( uint i=0; i<mTabProp.size(); i++ )
@@ -306,8 +299,8 @@ void KDFWidget::updateDF( void )
 /***************************************************************************
   * gets the signal when the diskList is complete and up to date
 **/
-void KDFWidget::updateDFDone( void )
-{
+void KDFWidget::updateDFDone( void ){
+
   mList->clear();
 
   int i=0;
@@ -323,35 +316,34 @@ void KDFWidget::updateDFDone( void )
     }
     else
     {
-      percent = i18n("Na");
-      size    = i18n("Na");
+      percent = i18n("N/A");
+      size    = i18n("N/A");
     }
 
     int k=0;
     item = new QListViewItem( mList, item );
-    if( mTabProp[0]->mVisible == true )
-    {
-      bool root = disk->mountOptions().find("user",0,false)==-1 ? true : false;
-      //QPixmap pix = mList->icon( disk->iconName(), root );
-      item->setPixmap( k++, mList->icon( disk->iconName(), root ) );
-    }
-    if( mTabProp[1]->mVisible == true )
-      item->setText( k++, disk->deviceName() );
-    if( mTabProp[2]->mVisible == true )
-      item->setText( k++, disk->fsType() );
-    if( mTabProp[3]->mVisible == true )
-      item->setText( k++, size );
-    if( mTabProp[4]->mVisible == true )
-      item->setText( k++, disk->mountPoint() );
-    if( mTabProp[5]->mVisible == true )
-      item->setText( k++, disk->prettyKBAvail() );
-    if( mTabProp[6]->mVisible == true )
-      item->setText( k++, percent );
+    bool root = disk->mountOptions().find("user",0,false)==-1 ? true : false;
+    item->setPixmap( k++, mList->icon( disk->iconName(), root ) );
+    item->setText( k++, disk->deviceName() );
+    item->setText( k++, disk->fsType() );
+    item->setText( k++, size );
+    item->setText( k++, disk->mountPoint() );
+    item->setText( k++, disk->prettyKBAvail() );
+    item->setText( k++, percent );
   }
   readingDF = false;
   updateDiskBarPixmaps();
+
+
 }
 
+/***************************************************************************
+  * Update display
+**/
+void KDFWidget::resizeEvent( QResizeEvent * )
+{
+   updateDiskBarPixmaps();
+}
 
 
  
@@ -369,6 +361,9 @@ void KDFWidget::criticallyFull( DiskEntry *disk )
 }
 
 
+/**************************************************************************
+  * find correct disk related to list item
+**/
 DiskEntry *KDFWidget::selectedDisk( QListViewItem *item )
 {
   if( item == 0 )
@@ -380,16 +375,33 @@ DiskEntry *KDFWidget::selectedDisk( QListViewItem *item )
     return(0);
   }
 
-  int i=0;
-  for(QListViewItem *it=mList->firstChild(); it!=0;it=it->nextSibling(),i++ )
+  DiskEntry disk(item->text(deviceCol));
+  disk.setMountPoint(item->text(mntCol));
+
+  // I can't get find() to work. The Disks::compareItems(..) is
+  // never called.
+  //
+  //int pos=mDiskList->find(disk);
+
+  int pos = -1;
+  for( u_int i=0; i<mDiskList.count(); i++ )
   {
-    if( it == item )
+    DiskEntry *item = mDiskList.at(i);
+    int res = disk.deviceName().compare( item->deviceName() );
+    if( res == 0 )
     {
-      return( mDiskList.at(i) );
+      res = disk.mountPoint().compare( item->mountPoint() );
+    }
+    if( res == 0 )
+    {
+      pos = i;
+      break;
     }
   }
 
-  return(0);
+
+  return mDiskList.at(pos);
+  //  return(0);
 }
 
 void KDFWidget::rightButtonPressed( QListViewItem *item, const QPoint &p, int )
@@ -444,19 +456,20 @@ void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
   }
   else if( position == 0 || position == 1 )
   {
-    item->setText( sizeCol, i18n("MOUNTING") );
-    item->setText( freeCol, i18n("MOUNTING") );
-    item->setPixmap( 0, mList->icon( "mini-clock", false ) );
-
-    int val = disk->toggleMount();
-    if( val != 0 /*== false*/ )
-    {
-      KMessageBox::error( this, disk->lastSysError() );
-    }
-    else if( mStd.openFileManager() == false || disk->mounted() == true )
-    {
-      openFileManager = true;
-    }
+      item->setText( sizeCol, i18n("MOUNTING") );
+      item->setText( freeCol, i18n("MOUNTING") );
+      item->setPixmap( 0, mList->icon( "mini-clock", false ) );
+      
+      int val = disk->toggleMount();
+      if( val != 0 /*== false*/ )
+	{
+	  KMessageBox::error( this, disk->lastSysError() );
+	}
+      else if ( ( mStd.openFileManager() == true)
+		&& (position == 0) ) //only on mount
+	{
+	  openFileManager = true;
+	}
   }
   else if( position == 2 )
   {
@@ -465,6 +478,7 @@ void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
 
   if( openFileManager == true )
   {
+    kdDebug() << "opening filemanager" << endl;
     if(  mStd.fileManager().isEmpty() == false ) 
     {
       QString cmd = mStd.fileManager();
@@ -495,10 +509,18 @@ void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
 **/
 void KDFWidget::updateDiskBarPixmaps( void )
 {
-  if( mBarColumn == -1 )
-  {
+  if (mTabProp[usageCol]->mVisible != true)
     return;
-  }
+
+
+  int size=0, w=0;
+
+   for(uint i=0; i<mTabProp.size()-1; i++ )
+     size += mList->columnWidth(i);
+   w=mList->width() - size - 4;
+   if (w<0)
+     w=0;
+   mList->setColumnWidth(usageCol, w );
 
   int h = mList->fontMetrics().lineSpacing()-2;
   if( h <= 0 )
@@ -509,12 +531,36 @@ void KDFWidget::updateDiskBarPixmaps( void )
   int i=0;
   for(QListViewItem *it=mList->firstChild(); it!=0;it=it->nextSibling(),i++ )
   {
-    DiskEntry *disk = mDiskList.at(i);
+    // I can't get find() to work. The Disks::compareItems(..) is
+    // never called.
+    //
+    //int pos=mDiskList->find(disk);
+    
+    DiskEntry dummy(it->text(deviceCol));
+    dummy.setMountPoint(it->text(mntCol));
+    int pos = -1;
+    for( u_int i=0; i<mDiskList.count(); i++ )
+      {
+	DiskEntry *item = mDiskList.at(i);
+	int res = dummy.deviceName().compare( item->deviceName() );
+	if( res == 0 )
+	  {
+	    res = dummy.mountPoint().compare( item->mountPoint() );
+	  }
+	if( res == 0 )
+	  {
+	    pos = i;
+	    break;
+	  }
+      }
+
+
+     DiskEntry *disk = mDiskList.at(pos);
     if( disk == 0 ) { continue; }
 
     if( disk->mounted() == true && disk->percentFull() != -1 )
     {
-      int w = mList->columnWidth(mBarColumn)-2;
+      int w = mList->columnWidth(usageCol)-2;
       if( w <= 0 ) { continue; } 
   
       QPixmap *pix = new QPixmap( w, h );
@@ -524,11 +570,17 @@ void KDFWidget::updateDiskBarPixmaps( void )
       QPainter p(pix);
       p.setPen(black);
       p.drawRect(0,0,w,h);
-      p.setBrush( disk->percentFull() > FULL_PERCENT ? red : darkGreen );
+      QColor c;
+      if ( (disk->iconName().find("cdrom") != -1)
+	   || (disk->iconName().find("writer") != -1) )
+	c = gray;
+      else
+	c = disk->percentFull() > FULL_PERCENT ? red : darkGreen;
+      p.setBrush(c );
       p.setPen(white);
       p.drawRect(1,1,(int)(((float)pix->width()-2)*(disk->percentFull()/100)),
 		 pix->height()-2);
-      it->setPixmap ( mBarColumn, *pix );
+      it->setPixmap ( usageCol, *pix );
       p.end();
       delete pix; 
     }
@@ -536,12 +588,8 @@ void KDFWidget::updateDiskBarPixmaps( void )
 }
 
 
-void KDFWidget::columnSizeChanged( int column, int, int newSize )
+void KDFWidget::columnSizeChanged( int, int, int )
 {
-  if( column != mBarColumn )
-  {
-    return;
-  }
 
   if( mTimer == 0 )
   {
