@@ -1,6 +1,6 @@
 /*
 
-    $Id: kedit.h,v 1.52 2000/10/11 04:42:01 waba Exp $
+    $Id: kedit.h,v 1.55 2001/01/21 07:22:58 waba Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -106,7 +106,7 @@ public:
     void setNewWindow() { newWindow = true; }
 
     /// List of all windows
-    static QList<TopLevel> windowList;
+    static QList<TopLevel> *windowList;
     QPopupMenu *right_mouse_button;
 
     bool queryExit( void );
@@ -116,7 +116,6 @@ protected:
     void setSensitivity();
 
     void readSettings();
-    void writeSettings();
     void setupEditWidget();
     void setupStatusBar();
     void setupActions();
@@ -134,6 +133,10 @@ private:
     KRecentFilesAction *recent;
     KToggleAction *statusbarAction;
     KToggleAction *toolbarAction;
+    KAction *cutAction;
+    KAction *copyAction;
+    KAction *undoAction;
+    KAction *redoAction;
 
     int open_mode;
     struct printinfo pi;
@@ -190,6 +193,7 @@ public slots:
     void toggleToolBar();
     void search_again();
     void toggle_overwrite();
+    void writeSettings();
 
     void spellcheck();
     void spell_started ( KSpell *);
