@@ -9,6 +9,8 @@
 #include <klocale.h>
 #include <kglobal.h>
 #include <kstatusbar.h>
+#include <kmessagebox.h>
+#include <kdebug.h>
 
 #include "kftabdlg.h"
 #include "kfwin.h"
@@ -18,11 +20,12 @@
 #include "kfind.moc"
 
 Kfind::Kfind(const KURL & url, QWidget *parent, const char *name)
-  : KDialogBase( Plain, i18n("Find Files"), 
+  : KDialogBase( Plain, QString::null, 
 	User1 | User2 | User3 | Close, User1, 
         parent, name, true, true,
 	i18n("&Find"), i18n("Stop"), i18n("Save...") )
 {
+  QWidget::setCaption( i18n("Find Files" ) );
   setButtonBoxOrientation(Vertical);
 
   enableButton(User1, true); // Enable "Search"
@@ -73,6 +76,11 @@ Kfind::~Kfind()
 {
 }
 
+void Kfind::closeEvent(QCloseEvent *)
+{
+   slotClose();
+}
+
 void Kfind::setProgressMsg(const QString &msg)
 {
    mStatusBar->changeItem(msg, 1);
@@ -130,8 +138,16 @@ void Kfind::slotResult(int errorCode)
     setStatusMsg(i18n("Ready."));
   else if (errorCode == KIO::ERR_USER_CANCELED)
     setStatusMsg(i18n("Aborted."));
+  else if (errorCode == KIO::ERR_DOES_NOT_EXIST)
+  {
+     setStatusMsg(i18n("Error."));
+     KMessageBox::sorry( this, i18n("Could not find the specified directory."));
+  }
   else
-    setStatusMsg(i18n("Error."));
+  {
+     kdDebug()<<"KIO error code: "<<errorCode<<endl;
+     setStatusMsg(i18n("Error."));
+  };
 
   enableButton(User1, true); // Enable "Search"
   enableButton(User2, false); // Disable "Stop"
