@@ -185,7 +185,7 @@ void CHexEditorWidget::writeConfiguration( KConfig &config )
   config.setGroup( "Display Font" );
   config.writeEntry( "UseSystemFont",        font.useSystemFont );
   config.writeEntry( "LocalFont",            font.localFont );
-  config.writeEntry( "NonPrintChar",         font.nonPrintChar );
+  config.writeEntry( "NonPrintChar",         font.nonPrintChar.unicode() );
 
   SDisplayCursor &cursor = mDisplayState.cursor;
   config.setGroup( "Display Cursor" );
@@ -1266,7 +1266,7 @@ void CHexEditorWidget::encode( CConversion::EMode mode )
     QString msg = i18n(""
       "The encoding you have selected is not reversible.\n"
       "If you revert to the original encoding later, there is no\n"
-      "guaranty that data can be restored to its original state.\n\n"
+      "guarantee that data can be restored to its original state.\n\n"
       "Proceed?");
     int reply = KMessageBox::warningYesNo( topLevelWidget(), msg,
 					   i18n("Encode") );
@@ -2587,3 +2587,4 @@ bool CHexEditorWidget::busy( bool showWarning )
 
 
 
+#include "hexeditorwidget.moc"
