@@ -347,12 +347,7 @@ void COptionDialog::setupFontPage( void )
   hline->setFrameStyle( QFrame::Sunken | QFrame::HLine );
   topLayout->addWidget( hline );
 
-  QStringList fixedList;
-  KFontChooser::getFontList( fixedList, "-*-*-*-*-*-*-*-*-*-*-m-*-*-*" );
-  fixedList.append("fixed"); // Not detected above!
-  fixedList.sort();
-
-  mFont.chooser = new KFontChooser( page, "font", true, fixedList, false, 4 );
+  mFont.chooser = new KFontChooser( page, "font", true, QStringList(), false, 4 );
   topLayout->addWidget( mFont.chooser );
   mFont.chooser->setFont( QFont( "courier", 12, QFont::Bold, FALSE ), true );
   mFont.chooser->setSampleText( i18n("KHexEdit editor font") );
