@@ -27,7 +27,7 @@
 
 #include <kapp.h>
 #include <kstdaccel.h>
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 
 #include "hexbuffer.h"
 #include "hexmanagerwidget.h"
@@ -45,7 +45,7 @@ class CAboutKHexEdit;
 class CDragLabel;
 
 
-class KHexEdit : public KTMainWindow
+class KHexEdit : public KMainWindow
 {
   enum StatusBarId
   {
@@ -241,11 +241,11 @@ class KHexEdit : public KTMainWindow
     void setStartupGeometry( void );
     bool eventFilter( QObject *obj, QEvent *event );
 
+    int acceleratorNumKey( uint index );
     inline CHexEditorWidget *editor( void );
     inline CHexToolWidget *converter( void );
-    inline CHexViewWidget *textView( void );
-    inline int acceleratorNumKey( uint index );
- 
+    inline CHexViewWidget *hexView( void );
+    
   private:
     static QList<KHexEdit> mWindowList;
     CHexManagerWidget *mManager;
@@ -266,6 +266,7 @@ class KHexEdit : public KTMainWindow
     KToolBarButton *mWriteProtectButton;
     CAboutKHexEdit *mAboutKHexEdit;
 
+    bool mIsModified;
     bool mShowToolBar;
     bool mShowStatusBar;
     bool mShowFullPath;
@@ -294,7 +295,7 @@ inline CHexEditorWidget *KHexEdit::editor( void )
   return( mManager->editor() );
 }
 
-inline CHexViewWidget *KHexEdit::textView( void )
+inline CHexViewWidget *KHexEdit::hexView( void )
 {
   return( mManager->editor()->view() );
 }
@@ -304,15 +305,6 @@ inline CHexToolWidget *KHexEdit::converter( void )
   return( mManager->converter() );
 }
 
-int KHexEdit::acceleratorNumKey( uint index )
-{
-  static int keys[9] = 
-  {
-    Key_1, Key_2, Key_3, Key_4, Key_5, Key_6, Key_7, Key_8, Key_9
-  };
-  return( index >= 9 ? -1 : keys[index] );
-}
-
 
 
 #endif
