@@ -19,14 +19,6 @@
 //  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-
-//
-// 1999-11-07-Espen Sand:
-// Cleaned up layout, AskFileName based on KDialogBase,
-// new Option dialog, QMessageBox -> KMessageBox
-//
-
-
 #include <qpopupmenu.h>
 #include <qkeycode.h>
 #include <qfile.h>
@@ -44,6 +36,7 @@
 #include <kstdaction.h>
 #include <kapp.h>
 #include <kfiledialog.h>
+#include <kdebug.h>
 
 #include <kiconloader.h>
 #include <kkeydialog.h>
@@ -54,11 +47,12 @@
 
 extern "C" {
 #include <unistd.h>
+#include <stdlib.h>
 };
 
 #include "KJotsMain.h"
 #include "SubjList.h"
-#include "ReadListConf.h"
+// #include "ReadListConf.h"
 #include "cpopmenu.h"
 #include "optiondialog.h"
 
@@ -167,7 +161,7 @@ void MyMultiEdit::openUrl()
 	      command = command.insert(pos, marked);
 	      command += " &";
 	    }
-	  system((const char *) command);
+	  system(QFile::encodeName(command));
 	  //debug("exec: %s", (const char *) command );
 	}
       else if( marked.left(6) == "ftp://" )
@@ -184,7 +178,7 @@ void MyMultiEdit::openUrl()
 	      command = command.insert(pos, marked);
 	      command += " &";
 	    }
-	  system((const char *) command);
+	  system(QFile::encodeName(command));
 	  //debug("exec: %s", (const char *) command );
 	}
     }
@@ -218,7 +212,7 @@ void MyButtonGroup::resizeEvent( QResizeEvent * )
 //----------------------------------------------------------------------
 
 KJotsMain::KJotsMain(const char* name)
-  : KTMainWindow( name )
+  : KMainWindow( 0, name )
 {
   mOptionDialog = 0;
   folderOpen    = FALSE;
@@ -229,7 +223,7 @@ KJotsMain::KJotsMain(const char* name)
   //
   f_main = new QFrame( this, "Frame_0" );
   f_main->setFrameStyle( QFrame::NoFrame );
-  setView(f_main, FALSE);
+  setCentralWidget(f_main);
 
   //
   // Text area
@@ -272,7 +266,9 @@ KJotsMain::KJotsMain(const char* name)
   l_folder->setFixedHeight( le_subject->sizeHint().height() );
 
   bg_top = new MyButtonGroup( f_main, "ButtonGroup_2" );
-  bg_top->setMinimumHeight( 32 ); // Bad!
+  QPushButton tp(0, "Test");
+  bg_top->setFixedHeight( tp.sizeHint().height()+8 );
+  bg_top->setMinimumWidth( HOT_LIST_SIZE * (BUTTON_WIDTH+4) + 6 );
   bg_top->setFrameStyle( QFrame::Box | QFrame::Sunken );
   bg_top->setExclusive(TRUE);
 
@@ -314,25 +310,28 @@ KJotsMain::KJotsMain(const char* name)
   config->setGroup("kjots");
 
   // read hotlist
-  config->readListEntry( "Hotlist", hotlist );
-  while( hotlist.count() > HOT_LIST_SIZE )
-    hotlist.removeLast();
-  // read list of folders
-  config->readListEntry( "Folders", folder_list );
 
-  QString temp;
+  hotlist = config->readListEntry( "Hotlist" );
+  while( hotlist.count() > HOT_LIST_SIZE )
+    hotlist.remove(hotlist.last());
+  // read list of folders
+  folder_list = config->readListEntry( "Folders" );
+
+  // create hotlist buttons and hotlist menu
   folders = new QPopupMenu;
   int i = 0;
   QPushButton *temp_button;
-  for( temp=folder_list.first(); !temp.isEmpty(); temp=folder_list.next(), i++)
+  for ( QStringList::Iterator it = folder_list.begin();
+        it != folder_list.end();
+        ++it, i++ )
   {
-    folders->insertItem(temp, i);
-    if( hotlist.contains(temp) )
+    folders->insertItem(*it, i);
+    if( hotlist.contains(*it) )
     {
-      temp_button = new QPushButton(temp, bg_top);
+      temp_button = new QPushButton(*it, bg_top);
       temp_button->setFocusPolicy(QWidget::ClickFocus);
       temp_button->setToggleButton(TRUE);
-      temp_button->setFixedSize(BUTTON_WIDTH,24);
+      temp_button->setFixedSize(BUTTON_WIDTH, temp_button->sizeHint().height());
       bg_top->insert(temp_button, i);
       button_list.append(temp_button);
     }
@@ -376,11 +375,11 @@ KJotsMain::KJotsMain(const char* name)
   keys->connectItem( "CopySelection", this, SLOT(copySelection()) );
   keys->readSettings();
 
-  
+
   // create menu
   int id;
   QPopupMenu *file = new QPopupMenu;
-  id = file->insertItem(i18n("&New Book"), this, SLOT(createFolder()));
+  id = file->insertItem(i18n("&New Book..."), this, SLOT(createFolder()));
   keys->changeMenuAccel(file, id, KStdAccel::New);
 
   file->insertSeparator();
@@ -411,7 +410,7 @@ KJotsMain::KJotsMain(const char* name)
 				     me_text, SLOT(paste()));
   keys->changeMenuAccel(edit_menu, id_e_paste, KStdAccel::Paste);
   edit_menu->insertSeparator();
-  
+
   // added actionized items (pfeiffer)
   KAction *action = KStdAction::find( this, SLOT( slotSearch() ), me_text );
   action->plug( edit_menu );
@@ -420,16 +419,33 @@ KJotsMain::KJotsMain(const char* name)
   action = KStdAction::replace( this, SLOT( slotReplace() ), me_text );
   action->plug( edit_menu );
   edit_menu->insertSeparator();
-  
-  id_e_new = edit_menu->insertItem(i18n("&New Page"),
-				   this, SLOT(newEntry()) );
-  keys->changeMenuAccel(edit_menu, id_e_new, "AddNewPage");
-  id_e_del = edit_menu->insertItem(i18n("&Delete Page"),
-				   this, SLOT(deleteEntry()) );
-  keys->changeMenuAccel(edit_menu, id_e_del, "DelPage");
+
+  // added more actionized items and toolbar (antonio)
+  action=new KAction(i18n("&New Page"), "filenew", 0, this,
+        SLOT(newEntry()), actionCollection(), "new_page");
+  action->plug( edit_menu );
+  action->plug( toolBar(0) );
+
+  action=new KAction(i18n("&Delete Page"), "editdelete", 0, this,
+        SLOT(deleteEntry()), actionCollection(), "del_page");
+  action->plug( edit_menu );
+  action->plug( toolBar(0) );
+
+  edit_menu->insertSeparator();
+  action=new KAction(i18n("Previous"), "back", 0, this,
+        SLOT(prevEntry()), actionCollection(), "new_page");
+  action->plug( edit_menu );
+  action->plug( toolBar(0) );
+
+  action=new KAction(i18n("Next"), "forward", 0, this,
+        SLOT(nextEntry()), actionCollection(), "del_page");
+  action->plug( edit_menu );
+  action->plug( toolBar(0) );
+
+  toolBar(0)->insertSeparator();
 
   QPopupMenu *options = new QPopupMenu;
-  options->insertItem(i18n("Configure &Key Bindings"),
+  options->insertItem(i18n("Configure &Key Bindings..."),
 		      this, SLOT(configureKeys()) );
   options->insertItem(i18n("&Configure %1...").arg(kapp->caption()),
 		      this, SLOT(configure()) );
@@ -440,6 +456,11 @@ KJotsMain::KJotsMain(const char* name)
   id_fav_del = hotlist->insertItem(i18n("Remove current book from hotlist"),
 				   this, SLOT(removeFromHotlist()) );
 
+  action=new KAction(i18n("Subject List"), "view_detailed", 0, this,
+        SLOT(toggleSubjList()), actionCollection(), "subject_list");
+  action->plug( hotlist );
+  action->plug( toolBar(0) );
+
   menuBar()->insertItem( i18n("&File"), file );
   menuBar()->insertItem( i18n("&Edit"), edit_menu );
   menuBar()->insertItem( i18n("&Books"), folders );
@@ -451,36 +472,7 @@ KJotsMain::KJotsMain(const char* name)
     " Christoph Neerfeld\n\rChristoph.Neerfeld@home.ivm.de";
   menuBar()->insertItem( i18n("&Help"), helpMenu(about ) );
 
-  //
-  // Make toolbar
-  //
-  QPixmap temp_pix;
-  temp_pix = BarIcon("filenew");
-  toolBar(0)->insertButton(temp_pix, 0, SIGNAL(clicked()), this,
-			   SLOT(newEntry()), TRUE, i18n("New"));
-  temp_pix = BarIcon("filedel");
-  toolBar(0)->insertButton(temp_pix, 1, SIGNAL(clicked()), this,
-			   SLOT(deleteEntry()), TRUE, i18n("Delete"));
-  temp_pix = BarIcon("back");
-  toolBar(0)->insertButton(temp_pix, 2, SIGNAL(clicked()), this,
-			   SLOT(prevEntry()), TRUE, i18n("Previous"));
-  temp_pix = BarIcon("forward");
-  toolBar(0)->insertButton(temp_pix, 3, SIGNAL(clicked()), this,
-			   SLOT(nextEntry()), TRUE, i18n("Next"));
-  toolBar(0)->insertSeparator();
-  temp_pix = BarIcon("openbook");
-  toolBar(0)->insertButton(temp_pix, 4, SIGNAL(clicked()), this,
-			   SLOT(toggleSubjList()), TRUE, i18n("Subject List"));
-  toolBar(0)->insertSeparator();
-  temp_pix = BarIcon("exit");
-
-  config->setGroup("kjots");
-  toolBar(0)->setBarPos(
-    (KToolBar::BarPosition)config->readNumEntry("ToolBarPos"));
-  enableToolBar(KToolBar::Show);
-
-
-  int nr = folder_list.find( config->readEntry("LastOpenFolder") );
+  int nr = folder_list.findIndex( config->readEntry("LastOpenFolder") );
   if( nr >= 0 )
   {
     openFolder(nr);
@@ -606,7 +598,6 @@ int KJotsMain::writeFile( QString name ) {
 
 void KJotsMain::openFolder(int id) {
   QPushButton *but;
-
   for( but = button_list.first(); but != NULL; but = button_list.next() )
     but->setOn(FALSE);
   but = (QPushButton *) bg_top->find(id);
@@ -616,9 +607,10 @@ void KJotsMain::openFolder(int id) {
   QDir dir = QDir( locateLocal("appdata", "") );
   QString file_name = dir.absPath();
   file_name += '/';
-  file_name += folder_list.at( folders->indexOf(id) );
+  file_name += *folder_list.at( folders->indexOf(id) );
   if( current_folder_name == file_name )
     return;
+
   if( folderOpen )
     saveFolder();
   current_folder_name = file_name;
@@ -626,7 +618,7 @@ void KJotsMain::openFolder(int id) {
   if( readFile(current_folder_name) < 0)
     {
       folderOpen = FALSE;
-      debug("Kjots: Unable to open folder");
+      kdDebug() << "Unable to open folder" << endl;
       return;
     }
 
@@ -637,12 +629,12 @@ void KJotsMain::openFolder(int id) {
   emit entryMoved(current);
   le_subject->setText(entrylist.first()->subject);
   folderOpen = TRUE;
-  l_folder->setText( folder_list.at(folders->indexOf(id)) );
+  l_folder->setText( *folder_list.at(folders->indexOf(id)) );
   me_text->setEnabled(TRUE);
   le_subject->setEnabled(TRUE);
   me_text->setFocus();
-  s_bar->setRange(0,entrylist.count()-1);
   s_bar->setValue(0);
+  s_bar->setRange(0,entrylist.count()-1);
 
   updateMenu();
 }
@@ -656,7 +648,6 @@ void KJotsMain::createFolder()
     delete ask;
     return;
   }
-
   QString name = ask->getName();
   delete ask;
   if( folder_list.contains(name) )
@@ -665,7 +656,6 @@ void KJotsMain::createFolder()
     KMessageBox::sorry( topLevelWidget(), msg );
     return;
   }
-
   saveFolder();
   entrylist.clear();
   folderOpen = TRUE;
@@ -678,12 +668,11 @@ void KJotsMain::createFolder()
   entrylist.append(new_entry);
   new_entry->subject = "";
   current = 0;
-  s_bar->setRange(0,0);
   s_bar->setValue(0);
+  s_bar->setRange(0,0);
   emit folderChanged(&entrylist);
   emit entryMoved(current);
   le_subject->setText(entrylist.first()->subject);
-
   folder_list.append(name);
 
   // TODO: this does not work with qt 2.0. Why?
@@ -712,7 +701,7 @@ void KJotsMain::deleteFolder()
   if( !folderOpen )
     return;
 
-  QString msg = i18n("Are you sure you want to delete the current book ?");
+  QString msg = i18n("Are you sure you want to delete the current book?");
   int result = KMessageBox::warningYesNo( topLevelWidget(), msg );
   if( result != KMessageBox::Yes )
   {
@@ -722,11 +711,11 @@ void KJotsMain::deleteFolder()
   QFileInfo fi(current_folder_name);
   QDir dir = fi.dir(TRUE);
   QString name = fi.fileName();
-  int index = folder_list.find(name);
+  int index = folder_list.findIndex(name);
   if( index < 0 )
     return;
   dir.remove(current_folder_name);
-  folder_list.remove(index);
+  folder_list.remove(folder_list.at(index));
   int id = folders->idAt(index);
   folders->removeItemAt(index);
   if( hotlist.contains(name) )
@@ -751,8 +740,8 @@ void KJotsMain::deleteFolder()
   le_subject->setEnabled(FALSE);
   le_subject->clear();
   emit folderChanged(&entrylist);
-  s_bar->setRange(0,0);
   s_bar->setValue(0);
+  s_bar->setRange(0,0);
   l_folder->clear();
   subj_list->repaint(TRUE);
 
@@ -884,7 +873,7 @@ void KJotsMain::addToHotlist()
   if( hotlist.contains(name) )
     return;
   hotlist.append(name);
-  int index = folder_list.find(name);
+  int index = folder_list.findIndex(name);
   if( index < 0 )
     return;
   int id = folders->idAt(index);
@@ -897,7 +886,7 @@ void KJotsMain::addToHotlist()
   config->sync();
   but->setFocusPolicy(QWidget::ClickFocus);
   but->setToggleButton(TRUE);
-  but->setFixedSize(BUTTON_WIDTH, 24);
+  but->setFixedSize(BUTTON_WIDTH, but->sizeHint().height());
   but->show();
   but->setOn(TRUE);
   bg_top->forceResize();
@@ -910,7 +899,7 @@ void KJotsMain::removeFromHotlist()
   if( !hotlist.contains(name) )
     return;
   hotlist.remove(name);
-  int index = folder_list.find(name);
+  int index = folder_list.findIndex(name);
   if( index < 0 )
     return;
   int id = folders->idAt(index);
@@ -1017,9 +1006,8 @@ void KJotsMain::writeBook()
     QFileInfo f_info(name);
     if( f_info.exists() )
     {
-      QString msg = i18n(""
-        "File already exists.\n"
-	"Do you want to overwrite it ? ");
+      QString msg = i18n("File already exists.\n"
+	                 "Do you want to overwrite it?");
       int result = KMessageBox::warningYesNo( topLevelWidget(), msg );
       if( result != KMessageBox::Yes )
       {
@@ -1061,9 +1049,8 @@ void KJotsMain::writePage()
     QFileInfo f_info(name);
     if( f_info.exists() )
     {
-      QString msg = i18n(""
-        "File already exists.\n"
-	"Do you want to overwrite it ? ");
+      QString msg = i18n("File already exists.\n"
+	                 "Do you want to overwrite it?");
       int result = KMessageBox::warningYesNo( topLevelWidget(), msg );
       if( result != KMessageBox::Yes )
       {
@@ -1133,3 +1120,4 @@ void KJotsMain::updateMenu()
   menuBar()->setItemEnabled(id_fav_add, activeBook);
   menuBar()->setItemEnabled(id_fav_del, activeBook);
 }
+#include "KJotsMain.moc"
