@@ -29,7 +29,7 @@
 #include <qdatetime.h>
 #include <qstring.h>
 #include <qlist.h>
-#include <qstrlist.h>
+#include <qstringlist.h>
 #include <qdialog.h>
 #include <qlineedit.h>
 #include <qbuttongroup.h>
@@ -37,7 +37,7 @@
 
 #include <kdialogbase.h>
 #include <keditcl.h>
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 
 class KJotsMain;
 class KToolBar;
@@ -115,7 +115,7 @@ protected:
 
 
 /////////////////////////////////////////////////////////////////////////////
-class KJotsMain : public KTMainWindow
+class KJotsMain : public KMainWindow
 {
   Q_OBJECT
 public:
@@ -172,8 +172,8 @@ protected:
   int              current;
   bool             folderOpen;
   QString          current_folder_name;
-  QStrList         folder_list;
-  QStrList         hotlist;
+  QStringList         folder_list;
+  QStringList         hotlist;
   QList<QPushButton> button_list;
   QPopupMenu      *folders;
   QFont            button_font;
