@@ -47,7 +47,11 @@ public slots:
   void select( int );
 
 protected slots:
-  void highlighted( int index ) { current = index; emit entryMoved(index); }
+  void highlighted( int index ) { 
+      current = index; 
+      if ( current >= 0 )
+	  emit entryMoved(index); 
+  }
 
 protected:
   KListBox         *lb_subj;
