@@ -84,7 +84,7 @@ int main( int argc, char **argv )
   KJotsMain *jots = new KJotsMain;
   if( a.isRestored() )
     {
-      if( KTMainWindow::canBeRestored(1) )
+      if( KJotsMain::canBeRestored(1) )
 	{
           jots->restore(1);
 	}
