@@ -6,7 +6,7 @@
  *
  * This file contains the docked widget for the laptop battery monitor
  *
- * $Id: daemondock.h,v 1.2 2000/03/27 21:58:37 pilone Exp $
+ * $Id: daemondock.h,v 1.3 2001/01/08 06:37:40 campbell Exp $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,6 +44,8 @@ private slots:
   void invokeStandby();
   void invokeSuspend();
   void invokeLockSuspend();
+  void invokeHibernation();
+  void invokeLockHibernation();
   void invokeSetup();
   void noop();
 
