@@ -62,8 +62,9 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
 	} else {
 		int can_standby = laptop_portable::has_standby();
 		int can_suspend = laptop_portable::has_suspend();
+		int can_hibernate = laptop_portable::has_hibernation();
 
-		if (!can_standby && !can_suspend)
+		if (!can_standby && !can_suspend && !can_hibernate)
 			apm = 0;
 		if (!apm) {
 			QVBoxLayout *top_layout = new QVBoxLayout(this, 12, 5);
@@ -102,6 +103,14 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
 			} else {
 				nopowerStandby = NULL;
 			}
+			if (can_hibernate) {
+				nopowerHibernate = new QRadioButton(i18n("Hibernate"), box1, "nohibernate");
+				nopowerHibernate->setMinimumSize(nopowerHibernate->sizeHint());
+				a0->addWidget(nopowerHibernate, 0);
+				nopowerBox->insert(nopowerHibernate);
+			} else {
+				nopowerHibernate = NULL;
+			}
 			nopowerOff = new QRadioButton(i18n("Off"), box1, "nooff");
 			nopowerOff->setMinimumSize(nopowerOff->sizeHint());
 			a0->addWidget(nopowerOff, 0);
@@ -143,6 +152,14 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
 			} else {
 				powerStandby = NULL;
 			}
+			if (can_hibernate) {
+				powerHibernate = new QRadioButton(i18n("Hibernate"), box2, "hibernate");
+				powerHibernate->setMinimumSize(powerHibernate->sizeHint());
+				a1->addWidget(powerHibernate, 0);
+				powerBox->insert(powerHibernate);
+			} else {
+				powerHibernate = NULL;
+			}
 			powerOff = new QRadioButton(i18n("Off"), box2, "off");
 			powerOff->setMinimumSize(powerOff->sizeHint());
 			a1->addWidget(powerOff, 0);
@@ -165,7 +182,7 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
 			top_layout->addWidget(explain, 0);
 
 			if (can_standby) {
-				QLabel* explain3 = new QLabel(i18n("Different laptops may respond to 'standby' in\ndifferent ways - in many it's only a temporary\nstate and may not be usefull for you."), this);
+				QLabel* explain3 = new QLabel(i18n("Different laptops may respond to 'standby' in\ndifferent ways - in many it's only a temporary\nstate and may not be useful for you."), this);
 				explain3->setMinimumSize(explain3->sizeHint());
 				top_layout->addWidget(explain3, 0);
 			}
@@ -243,6 +260,8 @@ int  PowerConfig::getNoPower()
 {
   if (!apm)
 	return(nopower);
+  if (nopowerHibernate && nopowerHibernate->isChecked())
+    return 3;
   if (nopowerStandby && nopowerStandby->isChecked())
     return 1;
   if (nopowerSuspend && nopowerSuspend->isChecked())
@@ -252,8 +271,10 @@ int  PowerConfig::getNoPower()
 
 int  PowerConfig::getPower()
 {
-	if (!apm || !powerOff)
-		return(power);
+  if (!apm || !powerOff)
+	return(power);
+  if (powerHibernate && powerHibernate->isChecked())
+    return 3;
   if (powerStandby && powerStandby->isChecked())
     return 1;
   if (powerSuspend && powerSuspend->isChecked())
@@ -275,11 +296,17 @@ void PowerConfig::setPower(int p, int np)
   } else {
 	if (np == 1) np = 0;
   }
+  if (nopowerHibernate) {
+	nopowerHibernate->setChecked(FALSE);
+  } else {
+	if (np == 3) np = 0;
+  }
   nopowerOff->setChecked(FALSE);
   switch (np) {
   case 0: nopowerOff->setChecked(TRUE);break;
   case 1: nopowerStandby->setChecked(TRUE);break;
   case 2: nopowerSuspend->setChecked(TRUE);break;
+  case 3: nopowerHibernate->setChecked(TRUE);break;
   }
   if (powerSuspend) {
 	powerSuspend->setChecked(FALSE);
@@ -291,11 +318,17 @@ void PowerConfig::setPower(int p, int np)
   } else {
 	if (p == 1) np = 0;
   }
+  if (powerHibernate) {
+	powerHibernate->setChecked(FALSE);
+  } else {
+	if (p == 3) np = 0;
+  }
   powerOff->setChecked(FALSE);
   switch (p) {
   case 0: powerOff->setChecked(TRUE);break;
   case 1: powerStandby->setChecked(TRUE);break;
   case 2: powerSuspend->setChecked(TRUE);break;
+  case 3: powerHibernate->setChecked(TRUE);break;
   }
 }
 
