@@ -33,12 +33,15 @@
 #include <kmessagebox.h>
 #include <kdebug.h>
 #include <ksimpleconfig.h>
+#include <kio/netaccess.h>
+#include <kurl.h>
 
 #include <qdir.h>
 #include <qfont.h>
 
 KNotesApp::KNotesApp()
-    : KSystemTray()
+    : KSystemTray(),
+	  DCOPObject("KNotesIface")
 {
     //create the dock widget....
     setPixmap( KGlobal::iconLoader()->loadIcon( "knotes", KIcon::Small ) );
@@ -54,29 +57,17 @@ KNotesApp::KNotesApp()
     menu->insertItem( i18n("Preferences..."), this, SLOT(slotPreferences(int)) );
     menu->insertItem( i18n("Notes"), m_note_menu );
 
-    //initialize saved notes, if none create a note...
-    QString str_notedir = KGlobal::dirs()->saveLocation( "appdata", "notes/" );
-    QDir notedir( str_notedir );
-    QStringList notes = notedir.entryList( QDir::Files, QDir::Name ); //doesn't list hidden files
-
-    for( QStringList::Iterator i = notes.begin(); i != notes.end(); ++i )
+    //remove old local config file if it still exists
+    QString configfile = KGlobal::dirs()->findResource( "config", "knotesrc" );
+	KSimpleConfig *test = new KSimpleConfig( configfile );
+    test->setGroup( "General" );
+    if ( test->readNumEntry( "version", 1 ) == 1 )
     {
-        QString configfile = notedir.absFilePath( *i );
-        KSimpleConfig* tmp = new KSimpleConfig( configfile );
-        tmp->setGroup( "General" );
-        int version = tmp->readNumEntry( "version", 1 );
-        delete tmp;
+		KIO::NetAccess::del( KURL( configfile ) );
+ 	}
+   	delete test;
 
-        KNote* tmpnote = new KNote( configfile, version == 1 );
-
-        connect( tmpnote, SIGNAL( sigRenamed(QString&, QString&) ),
-                 this,    SLOT  ( slotNoteRenamed(QString&, QString&) ) );
-        connect( tmpnote, SIGNAL( sigNewNote(int) ),
-                 this,    SLOT  ( slotNewNote(int) ) );
-        connect( tmpnote, SIGNAL( sigKilled(QString) ),
-                 this,    SLOT  ( slotNoteKilled(QString) ) );
-        m_NoteList.insert( tmpnote->getName(), tmpnote );
-    }
+    loadNotes();
 
     if( m_NoteList.count() == 0 && !kapp->isRestored() )
         slotNewNote();
@@ -89,80 +80,130 @@ KNotesApp::~KNotesApp()
     m_NoteList.clear();
 }
 
-void KNotesApp::copyDefaultConfig( QString& sc_filename, QString& newname )
+void KNotesApp::loadNotes()
 {
-    QString defaultsfile = KGlobal::dirs()->findResource( "config", "knotesrc" );
-    KSimpleConfig defaults( defaultsfile );
-    KSimpleConfig sc( sc_filename );
+    QString str_notedir = KGlobal::dirs()->saveLocation( "appdata", "notes/" );
+    QDir notedir( str_notedir );
+    QStringList notes = notedir.entryList( QDir::Files, QDir::Name ); //doesn't list hidden files
 
-    sc.setGroup( "Display" );
-    defaults.setGroup( "Display" );
+    for( QStringList::Iterator i = notes.begin(); i != notes.end(); ++i )
+    {
+        //check to see if this note is already shown...
+        if( m_NoteList[ *i ] )
+            continue;
 
-    uint width  = defaults.readUnsignedNumEntry( "width", 200 );
-    uint height = defaults.readUnsignedNumEntry( "height", 200 );
-    QColor bgc  = defaults.readColorEntry( "bgcolor", &(Qt::yellow) );
-    QColor fgc  = defaults.readColorEntry( "fgcolor", &(Qt::black) );
+        newNote( *i );
+    }
+}
 
-    sc.writeEntry( "width", width );
-    sc.writeEntry( "height", height );
-    sc.writeEntry( "bgcolor", bgc );
-    sc.writeEntry( "fgcolor", fgc );
+/* virtual */ ASYNC KNotesApp::showNote( const QString& name )
+{
+    KNote* tmpnote = m_NoteList[name];
+    if (!tmpnote)
+    {
+    	kdWarning() << "No note named " << name << endl;
+	return;
+    }
+    if( !tmpnote->isHidden() )
+    {
+        KWin::setActiveWindow(tmpnote->winId());
+        tmpnote->setFocus();
+    }
+    else
+    {
+        //if not show it on the current desktop
+        tmpnote->show();
+        tmpnote->slotToDesktop( KWin::currentDesktop() );
+        KWin::setActiveWindow(tmpnote->winId());
+        tmpnote->setFocus();
+    }
+}
 
-    sc.setGroup( "Editor" );
-    defaults.setGroup( "Editor" );
+ASYNC KNotesApp::rereadNotesDir()
+{
+    loadNotes();
+}
 
-    uint tabsize = defaults.readUnsignedNumEntry( "tabsize", 4 );
-    bool indent  = defaults.readBoolEntry( "autoindent", true );
+ASYNC KNotesApp::addNote( QString title, QString body,
+                          unsigned long pilotID )
+{
+    newNote( title, body );
 
-    sc.writeEntry( "tabsize", tabsize );
-    sc.writeEntry( "autoindent", indent );
+	KNote* tmp = m_NoteList[title];
+	if( tmp )
+	{
+	    QDir appdir( KGlobal::dirs()->saveLocation( "appdata", "notes/" ) );
+        QString sc_filename = appdir.absFilePath( title );
 
-    QFont def_font( "helvetica" );
-    QFont currfont = defaults.readFontEntry( "font", &def_font );
-    sc.writeEntry( "font", currfont );
-
-    sc.setGroup( "Actions" );
-    defaults.setGroup( "Actions" );
-
-    QString mailstr  = defaults.readEntry( "mail", "kmail --msg %f" );
-    QString printstr = defaults.readEntry( "print", "a2ps -P %p -1 --center-title=%t --underlay=KDE %f" );
-
-    sc.writeEntry( "mail", mailstr );
-    sc.writeEntry( "print", printstr );
-
-    sc.setGroup( "General" );
-    sc.writeEntry( "version", 2 );
-
-    sc.setGroup( "Data" );
-    sc.writeEntry( "name", newname );
-
-    // TODO: write default entries for the group "WindowDisplay"
-
-    sc.sync();
+        KSimpleConfig sc( sc_filename );
+        sc.setGroup( "KPilot" );
+        sc.writeEntry( "pilotID", pilotID );
+        sc.sync();
+	}
+	else
+	{
+	    kdError() << "could not add note via dcop: " << title << endl;
+	}
 }
 
 void KNotesApp::slotNewNote( int /*id*/ )
 {
-    QString datadir = KGlobal::dirs()->saveLocation( "appdata", "notes/" );
+    newNote();
+}
 
-    //find a new appropriate id for the new note...
-    QString thename, configfile;
-    QDir appdir( datadir );
+void KNotesApp::newNote( const QString& note_name, const QString& text )
+{
+    QDir appdir( KGlobal::dirs()->saveLocation( "appdata", "notes/" ) );
+    QString thename;
 
-    for( int i = 1; ; i++ )
+    //handle cases for the name
+    if( note_name.isEmpty() )
     {
-        thename = QString( "KNote %1" ).arg(i);
-
-        if( !appdir.exists( thename ) )
+        //find a suitable name
+        for( int i = 1; ; i++ )
         {
-            configfile = appdir.absFilePath( thename );
-            break;
+            thename = QString( "KNote %1" ).arg(i);
+            if( !appdir.exists( thename ) )
+                break;
+        }
+    }
+    else
+    {
+        thename = note_name;
+        if( m_NoteList[thename] )
+        {
+            kdError() << "This note is already showing" << endl;
+            return;
         }
     }
 
-    copyDefaultConfig( configfile, thename );
+    //handle the cases for if there is already a config file...
+    QString config = appdir.absFilePath( thename );
+    if( !appdir.exists( thename ) )
+    {
+        KIO::NetAccess::copy( KURL( KGlobal::dirs()->findResource( "config", "knotesrc" ) ),
+                              KURL( config ) );
+    }
+
+    KSimpleConfig sc( config );
+    sc.setGroup( "General" );
+    int version = sc.readNumEntry( "version", 1 );
+
+    if( version == 2 )
+    {
+	    sc.setGroup( "Data" );
+        if( sc.readEntry( "name" ) != thename )
+	    {
+            sc.writeEntry( "name", thename );
+            sc.sync();
+        }
+    }
+
+    KNote* newnote = new KNote( config, version == 1 );
+
+    if( !text.isEmpty() )
+        newnote->setText( text );
 
-    KNote* newnote = new KNote( configfile );
     connect( newnote, SIGNAL( sigRenamed(QString&, QString&) ),
              this,    SLOT( slotNoteRenamed(QString&, QString&) ) );
     connect( newnote, SIGNAL( sigNewNote(int) ),
@@ -170,7 +211,7 @@ void KNotesApp::slotNewNote( int /*id*/ )
     connect( newnote, SIGNAL( sigKilled(QString) ),
              this,    SLOT( slotNoteKilled(QString) ) );
 
-    m_NoteList.insert( thename, newnote );
+    m_NoteList.insert( newnote->getName(), newnote );
 }
 
 void KNotesApp::slotNoteRenamed( QString& oldname, QString& newname )
@@ -199,20 +240,7 @@ void KNotesApp::slotToNote( int id )
 
     //if it's already showing, we need to change to its desktop
     //and give it focus
-    KNote* tmpnote = m_NoteList[name];
-    if( !tmpnote->isHidden() )
-    {
-        KWin::setActiveWindow(tmpnote->winId());
-        tmpnote->setFocus();
-    }
-    else
-    {
-        //if not show it on the current desktop
-        tmpnote->show();
-        tmpnote->slotToDesktop( KWin::currentDesktop() );
-        KWin::setActiveWindow(tmpnote->winId());
-        tmpnote->setFocus();
-    }
+    showNote(name);
 }
 
 void KNotesApp::slotPrepareNoteMenu()
