@@ -6,22 +6,21 @@
 #ifndef PREFS_H
 #define PREFS_H
 
-#include <qdialog.h>
-#include <qradiobt.h>
-#include <qlabel.h>
-#include <qbttngrp.h>
+#include <kdialogbase.h>
 
-class Preferences : public QDialog {
-    Q_OBJECT
-public:
-    Preferences();
+class Preferences : public KDialogBase 
+{
+  Q_OBJECT
 
-public slots:
+  public:
+    Preferences( QWidget *parent=0, const char *name=0, bool modal=true );
+
+  public slots:
     void update_boxes();
     void update_reality(int);
     void closed();
 
-signals:
+  signals:
     void prefs_change();
 };
 
