@@ -46,7 +46,7 @@
 extern "C" int getpagesize();	// argh, have to define prototype!
 #endif
 
-#ifdef linux
+#ifdef __linux__
 // -- global constants ---------------------------------------------------
 static const char *STAT_NAME = "stat";
 static const char *MEMINFO_NAME = "meminfo";
@@ -80,14 +80,14 @@ void KSample::Sample::fill(unsigned scale)
 // the proc filesystem; for other platforms perform equivalent initialisation
 KSample::KSample(KTimeMon *t, bool a, unsigned p, unsigned s, unsigned c) :
   timemon(t),
-#ifdef linux
+#ifdef __linux__
   memFD(-1), statFD(-1),
 #elif defined (__sun__)
   kc(0), warned(false),
 #endif
   pageScale(p), swapScale(s), cxScale(c), autoscale(a)
 {
-#ifdef linux
+#ifdef __linux__
 
   parseMtab(proc);
 
@@ -105,9 +105,9 @@ KSample::KSample(KTimeMon *t, bool a, unsigned p, unsigned s, unsigned c) :
   snprintf(file, sizeof(file), "%s/%s", proc, STAT_NAME);
   if ((statFD = open(file, O_RDONLY)) == -1) {
     KMessageBox::error(timemon,
-                       i18n("Sorry, I cannot open the file `%s'.\nThe diagnostics are: %s.\n\n"
+                       i18n("Sorry, I cannot open the file `%1'.\nThe diagnostics are: %2.\n\n"
                             "I need this file  to determine current system info.\n"
-                            "Maybe your proc filesystem is non Linux-standard?"));
+                            "Maybe your proc filesystem is non Linux-standard?").arg(file).arg(strerror(errno)));
     exit(1);
   }
 
@@ -115,7 +115,7 @@ KSample::KSample(KTimeMon *t, bool a, unsigned p, unsigned s, unsigned c) :
   if ((kc = kstat_open()) == 0) {
     KMessageBox::error(timemon, i18n("Sorry, I cannot initialise the `kstat' library.\n"
                                      "This library is used for accessing kernel information.\n"
-                                     "The diagnostics are: `%s'.\n\n"
+                                     "The diagnostics are: `%1'.\n\n"
                                      "Are you running Solaris at all?\n"
                                      "You may want to mail me at mueller@kde.org,\n"
                                      "I will try to figure out what went wrong.").arg(strerror(errno)));
@@ -135,7 +135,7 @@ KSample::KSample(KTimeMon *t, bool a, unsigned p, unsigned s, unsigned c) :
 // Get rid of the resources we acquired in the constructor.
 KSample::~KSample()
 {
-#ifdef linux
+#ifdef __linux__
   close(memFD);
   close(statFD);
 #elif defined (__sun__)
@@ -143,7 +143,7 @@ KSample::~KSample()
 #endif
 }
 
-#ifdef linux
+#ifdef __linux__
 // Parse /etc/mtab to determine the proc filesystem mount point.
 void KSample::parseMtab(char *dest)
 {
@@ -246,7 +246,7 @@ void KSample::readSample()
 {
     sample.cpus = 0;		// just to make sure...
 
-#ifdef linux			// linux makes it simple: use the /proc if
+#ifdef __linux__		// linux makes it simple: use the /proc if
     int l;
     char buffer[4096];
 
@@ -441,9 +441,9 @@ void KSample::readSample()
     if ((ksp = kstat_lookup(kc, "unix", -1, "system_pages")) == 0 ||
         kstat_read(kc, ksp, 0) == -1)
         fatal(i18n("Sorry, I cannot read the memory statistics entry\n"
-                   "from the `kstat' library. The diagnostics are `%1' and ksp is %2.\n\n"
+                   "from the `kstat' library. The diagnostics are `%1'\n\n"
                    "You might want to contact me at\n"
-                   "mueller@kde.org and I will try to sort this out.").arg(strerror(errno)).arg(ksp));
+                   "mueller@kde.org and I will try to sort this out.").arg(strerror(errno)));
 
     int i;
     unsigned long physmem = 0, freemem = 0, availrmem = 0;
@@ -528,7 +528,7 @@ void KSample::updateSample()
 // Convert v to a value representing megabytes.
 inline void KSample::makeMBytes(unsigned long &v)
 {
-#ifdef linux
+#ifdef __linux__
     v /= 1024;			// can it be simpler ;-)
 #elif defined (__osf__) || defined(__sun__)
     v /= pagesPerMB;
